==> downloaders-1.0.21.tar.gz: downloaders-1.0.21/setup.py <==
import os
import re

# To use a consistent encoding
from codecs import open as copen

from setuptools import find_packages, setup

here = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the relevant file
with copen(os.path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()


def read(*parts):
    with copen(os.path.join(here, *parts), "r") as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


__version__ = find_version("downloaders", "__version__.py")

test_deps = [
    "pytest",
    "validate_version_code",
]

extras = {
    "test": test_deps,
}

setup(
    name="downloaders",
    version=__version__,
    description="Python package to handle download of multiple types of files.",
    long_description=long_description,
    url="https://github.com/LucaCappelletti94/downloaders",
    author="LucaCappelletti94",
    author_email="cappelletti.luca94@gmail.com",
    # Choose your license
    license="MIT",
    include_package_data=True,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    packages=find_packages(exclude=["contrib", "docs", "tests*"]),
    tests_require=test_deps,
    # Add here the package dependencies
    install_requires=["tqdm", "requests", "pandas"],
    extras_require=extras,
)

==> downloaders-1.0.22.tar.gz: downloaders-1.0.22/setup.py <==
"""Setup for the downloaders package."""

import os
import re

# To use a consistent encoding
from codecs import open as copen

from setuptools import find_packages, setup

here = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the relevant file
with copen(os.path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def read(*parts):
    with copen(os.path.join(here, *parts), "r") as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


__version__ = find_version("downloaders", "__version__.py")

test_deps = [
    "pytest",
    "types-tqdm",
    "types-requests",
    "pandas-stubs",
    "validate_version_code",
]

extras = {
    "test": test_deps,
}

setup(
    name="downloaders",
    version=__version__,
    description="Python package to handle download of multiple types of files.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/LucaCappelletti94/downloaders",
    author="LucaCappelletti94",
    author_email="cappelletti.luca94@gmail.com",
    license="MIT",
    include_package_data=True,
    # Must have at least python 3.8
    python_requires=">=3.8",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    packages=find_packages(exclude=["contrib", "docs", "tests*"]),
    tests_require=test_deps,
    # Add here the package dependencies
    install_requires=["tqdm", "requests", "pandas"],
    extras_require=extras,
)
